@@ -287,8 +287,8 @@ if use_platform_dirs():
     SYSTEM_CONFIG_PATH = platformdirs.site_config_dir(
         APPNAME, appauthor=False, multipath=True
     ).split(os.pathsep)
-else:
-    if os.name == "nt":  # noqa
+else:  # noqa: PLR5501
+    if os.name == "nt":
         programdata = os.environ.get("PROGRAMDATA", None)
         if programdata:  # noqa
             SYSTEM_CONFIG_PATH = [os.path.join(programdata, "jupyter")]
@@ -388,7 +388,10 @@ def is_file_hidden_win(abs_path: str, stat_res: Optional[Any] = None) -> bool:
             raise
 
     try:
-        if stat_res.st_file_attributes & stat.FILE_ATTRIBUTE_HIDDEN:  # type:ignore
+        if (
+            stat_res.st_file_attributes  # type:ignore[union-attr]
+            & stat.FILE_ATTRIBUTE_HIDDEN  # type:ignore[attr-defined]
+        ):
             return True
     except AttributeError:
         # allow AttributeError on PyPy for Windows
@@ -600,7 +603,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
     )
 
     class ACL(ctypes.Structure):
-        _fields_ = [
+        _fields_ = [  # noqa
             ("AclRevision", wintypes.BYTE),
             ("Sbz1", wintypes.BYTE),
             ("AclSize", wintypes.WORD),
@@ -612,7 +615,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
     PACL = ctypes.POINTER(ACL)
     PSECURITY_DESCRIPTOR = ctypes.POINTER(wintypes.BYTE)
 
-    def _nonzero_success(result, func, args):
+    def _nonzero_success(result: int, func: Any, args: Any) -> Any:
         if not result:
             raise ctypes.WinError(ctypes.get_last_error())  # type:ignore[attr-defined]
         return args
@@ -714,7 +717,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
         wintypes.DWORD,  # DWORD dwAclRevision
     )
 
-    def CreateWellKnownSid(WellKnownSidType):
+    def CreateWellKnownSid(WellKnownSidType: Any) -> Any:
         # return a SID for predefined aliases
         pSid = (ctypes.c_char * 1)()
         cbSid = wintypes.DWORD()
@@ -727,7 +730,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
             advapi32.CreateWellKnownSid(WellKnownSidType, None, pSid, ctypes.byref(cbSid))
         return pSid[:]
 
-    def GetUserNameEx(NameFormat):
+    def GetUserNameEx(NameFormat: Any) -> Any:
         # return the user or other security principal associated with
         # the calling thread
         nSize = ctypes.pointer(ctypes.c_ulong(0))
@@ -742,7 +745,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
         secur32.GetUserNameExW(NameFormat, lpNameBuffer, nSize)
         return lpNameBuffer.value
 
-    def LookupAccountName(lpSystemName, lpAccountName):
+    def LookupAccountName(lpSystemName: Any, lpAccountName: Any) -> Any:
         # return a security identifier (SID) for an account on a system
         # and the name of the domain on which the account was found
         cbSid = wintypes.DWORD(0)
@@ -777,12 +780,12 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
             raise ctypes.WinError()  # type:ignore[attr-defined]
         return pSid, lpReferencedDomainName.value, peUse.value
 
-    def AddAccessAllowedAce(pAcl, dwAceRevision, AccessMask, pSid):
+    def AddAccessAllowedAce(pAcl: Any, dwAceRevision: Any, AccessMask: Any, pSid: Any) -> Any:
         # add an access-allowed access control entry (ACE)
         # to an access control list (ACL)
         advapi32.AddAccessAllowedAce(pAcl, dwAceRevision, AccessMask, pSid)
 
-    def GetFileSecurity(lpFileName, RequestedInformation):
+    def GetFileSecurity(lpFileName: Any, RequestedInformation: Any) -> Any:
         # return information about the security of a file or directory
         nLength = wintypes.DWORD(0)
         try:
@@ -808,15 +811,19 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
         )
         return pSecurityDescriptor
 
-    def SetFileSecurity(lpFileName, RequestedInformation, pSecurityDescriptor):
+    def SetFileSecurity(
+        lpFileName: Any, RequestedInformation: Any, pSecurityDescriptor: Any
+    ) -> Any:
         # set the security of a file or directory object
         advapi32.SetFileSecurityW(lpFileName, RequestedInformation, pSecurityDescriptor)
 
-    def SetSecurityDescriptorDacl(pSecurityDescriptor, bDaclPresent, pDacl, bDaclDefaulted):
+    def SetSecurityDescriptorDacl(
+        pSecurityDescriptor: Any, bDaclPresent: Any, pDacl: Any, bDaclDefaulted: Any
+    ) -> Any:
         # set information in a discretionary access control list (DACL)
         advapi32.SetSecurityDescriptorDacl(pSecurityDescriptor, bDaclPresent, pDacl, bDaclDefaulted)
 
-    def MakeAbsoluteSD(pSelfRelativeSecurityDescriptor):
+    def MakeAbsoluteSD(pSelfRelativeSecurityDescriptor: Any) -> Any:
         # return a security descriptor in absolute format
         # by using a security descriptor in self-relative format as a template
         pAbsoluteSecurityDescriptor = None
@@ -870,7 +877,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
         )
         return pAbsoluteSecurityDescriptor
 
-    def MakeSelfRelativeSD(pAbsoluteSecurityDescriptor):
+    def MakeSelfRelativeSD(pAbsoluteSecurityDescriptor: Any) -> Any:
         # return a security descriptor in self-relative format
         # by using a security descriptor in absolute format as a template
         pSelfRelativeSecurityDescriptor = None
@@ -892,7 +899,7 @@ def _win32_restrict_file_to_user_ctypes(fname: str) -> None:  # noqa
         )
         return pSelfRelativeSecurityDescriptor
 
-    def NewAcl():
+    def NewAcl() -> Any:
         # return a new, initialized ACL (access control list) structure
         nAclLength = 32767  # TODO: calculate this: ctypes.sizeof(ACL) + ?
         acl_data = ctypes.create_string_buffer(nAclLength)
@@ -989,10 +996,8 @@ def secure_write(fname: str, binary: bool = False) -> Iterator[Any]:
                     issue_insecure_write_warning()
                 else:
                     msg = (
-                        "Permissions assignment failed for secure file: '{file}'."
-                        " Got '{permissions}' instead of '0o0600'.".format(
-                            file=fname, permissions=oct(file_mode)
-                        )
+                        f"Permissions assignment failed for secure file: '{fname}'."
+                        f" Got '{oct(file_mode)}' instead of '0o0600'."
                     )
                     raise RuntimeError(msg)
         yield f
@@ -1001,7 +1006,7 @@ def secure_write(fname: str, binary: bool = False) -> Iterator[Any]:
 def issue_insecure_write_warning() -> None:
     """Issue an insecure write warning."""
 
-    def format_warning(msg, *args, **kwargs):
+    def format_warning(msg: str, *args: Any, **kwargs: Any) -> str:
         return str(msg) + "\n"
 
     warnings.formatwarning = format_warning  # type:ignore[assignment]
